@@ -152,6 +152,25 @@ class AmocrmRunner:
         elif self.action == "clean_s3":
             self.clean_s3()
 
+    def regenerate_file_secret(self, code_auth):
+        """
+        If file secrete doesn't exist call this mide
+        :param code_auth: get it from amocrm UI -> integration API
+        :return: Nothing
+        """
+        from amocrm.api.api_loader_amocrm_v4 import AmocrmApiLoader as ApiLoader
+        args_api = {"amocrm_api_url": self.amocrm_api_url}
+        args_api.update(self.amocrm_secrets)
+        api_loader = ApiLoader(
+            self.entity,
+            self.s3_client,
+            args_api,
+            date_modified_from=self.date_modified_from,
+            with_offset=self.with_offset,
+            batch_api=self.batch_api,
+        )
+        api_loader.auth(code_auth=code_auth)
+
     def extract(self):
         """
         1. step to run. Extract from amocrm.api
